import bpy
from bpy.props import *
from mathutils import Color
from ... base_types import AnimationNode

groupNotFoundMessage = "Group not found"
noMeshMessage = "Mesh object required"
differentNumberOfVertsMessage = "Invalid number of input vectors"

class VertexColors(bpy.types.Node, AnimationNode):
    bl_idname = "an_mySetVertexColors"
    bl_label = "Set Vertex Colors"
    
    errorMessage = StringProperty();
    myLabel = StringProperty(); 
    
    def create(self):
        self.newInput("Object", "Object", "source")
        self.newInput("Integer", "Vertex Color Index", "vertexColorIndex")
        self.newInput("Vector List", "Color Vectors", "colorVectorsIn")
    
    
    def draw(self, layout):
        #layout.prop(self,,text)
        if self.errorMessage != "":
            layout.label(self.errorMessage, icon = "ERROR")
                          
    def execute(self, source, vertexColorIndex, colorVectorsIn):
            self.errorMessage = ""
            
            if source is None:
                self.errorMessage = noMeshMessage
                return

            if source.type != "MESH":
                self.errorMessage = noMeshMessage
                return

            if len(source.data.vertex_colors) == 0:
                source.data.vertex_colors.new()
            
            print(source.data.vertex_colors)
            
            vertexColorGroup = self.getVertexColorGroup(source, vertexColorIndex)

            if vertexColorGroup is None:
                self.errorMessage = groupNotFoundMessage
                return
            
        
            myColors = source.data.polygons.data.vertex_colors[vertexColorIndex].data
            
            if len(myColors) != len(colorVectorsIn):
                self.errorMessage = differentNumberOfVertsMessage
                return

            for i in range(len(myColors)):
                myColors[i].color = colorVectorsIn[i]
                        

                
    def getVertexColorGroup(self, object, identifier):
        try:return object.data.vertex_colors[identifier]
        except: return None